@@ -2,10 +2,12 @@ try:
     from ..core.exceptions import BadInput, handler, typeChecker, \
         UNSETVALUE, UnknownTechniqueProperty, BadType
     from ..core.metadata import Metadata, MetaDiv
+    from ..core.helpers import handle_object_placement
 except ImportError:
     from core.exceptions import BadInput, handler, typeChecker, \
         UNSETVALUE, UnknownTechniqueProperty, BadType
     from core.metadata import Metadata, MetaDiv
+    from core.helpers import handle_object_placement
 
 
 class Technique:
@@ -100,18 +102,19 @@ class Technique:
     @metadata.setter
     def metadata(self, metadata):
         typeChecker(type(self).__name__, metadata, list, "metadata")
-        self.__metadata = []
-        entry = ""
-        try:
-            for entry in metadata:
-                if "divider" in entry:
-                    self.__metadata.append(MetaDiv(entry["divider"]))
-                else:
-                    self.__metadata.append(Metadata(entry['name'], entry['value']))
-        except KeyError as e:
-            handler(type(self).__name__, 'Metadata {} is missing parameters: '
-                                         '{}. Unable to load.'
-                    .format(entry, e))
+        if not handle_object_placement(self.__metadata, metadata, Metadata):
+            self.__metadata = []
+            entry = ""
+            try:
+                for entry in metadata:
+                    if "divider" in entry:
+                        self.__metadata.append(MetaDiv(entry["divider"]))
+                    else:
+                        self.__metadata.append(Metadata(entry['name'], entry['value']))
+            except KeyError as e:
+                handler(type(self).__name__, 'Metadata {} is missing parameters: '
+                                             '{}. Unable to load.'
+                        .format(entry, e))
 
     @property
     def showSubtechniques(self):
